@@ -1,7 +1,7 @@
 AtmosphericEmissivity <- function (airtemp, cloudiness, vp=NULL, opt="linear") 
 {
-    if (opt == "Brutseart") {
-		if(is.null(vp)){ print("To use Brutseart's 1975 Clear-Sky Emissivity eqn, enter vapor pressure in kPa")
+    if (opt == "Brutsaert") {
+		if(is.null(vp)){ print("To use Brutsaert's 1975 Clear-Sky Emissivity eqn, enter vapor pressure in kPa")
 			} else return((1.24*((vp*10)/(T+273.2))^(1/7)) * (1 - 0.84 * cloudiness) + 
 				0.84 * cloudiness)
 	} else {
